@@ -6,14 +6,16 @@ from .denomination import Denomination
 from .call import Call
 from .suit import Suit
 from .auction import Auction
-from .constants import (CONTRACTS, SEATS, SUITS,
+from .constants import (
+    CONTRACTS, SEATS, SUITS,
     UNDER_TRICK_POINTS, UNDER_TRICK_POINTS_DOUBLED, UNDER_TRICK_POINTS_REDOUBLED,
     CONTRACT_POINTS, CONTRACT_POINTS_DOUBLED, CONTRACT_POINTS_REDOUBLED,
     OVER_TRICK_POINTS, OVER_TRICK_POINTS_DOUBLED, OVER_TRICK_POINTS_REDOUBLED,
     PART_GAME_BONUS, GAME_BONUS,
-    GAME_TRICKS, CONTRACT_THRESHOLD, DOUBLED_BONUS, REDOUBLED_BONUS,
+    CONTRACT_THRESHOLD, DOUBLED_BONUS, REDOUBLED_BONUS,
     SLAM_LEVEL, GRAND_SLAM_LEVEL,
-    SLAM_BONUS, GRAND_SLAM_BONUS)
+    SLAM_BONUS, GRAND_SLAM_BONUS
+    )
 
 __all__ = ['Contract']
 
@@ -36,7 +38,7 @@ class Contract(object):
     It is also identified (if appropriate) as either major, minor or no trumps.
     """
 
-    def __init__(self, name: str='', declarer: str='', auction: Union[Auction, None]=None):
+    def __init__(self, name: str = '', declarer: str = '', auction: Union[Auction, None] = None):
         (self._name, self._modifier) = self._get_name(name)
         self._declarer = declarer
         self.auction = self._analyse_auction(auction)
@@ -268,7 +270,7 @@ class Contract(object):
                 return False
         return True
 
-    def score(self, declarer_tricks: int, vulnerable: bool= False) -> int:
+    def score(self, declarer_tricks: int, vulnerable: bool = False) -> int:
         """Return the score for a contract."""
         # Based on https://en.wikipedia.org/wiki/Bridge_scoring#Contract_points
 
@@ -289,13 +291,6 @@ class Contract(object):
         score += self._game_bonus(declarer_tricks, vulnerable, contract_points)
         score += self._overtrick_points(declarer_tricks, vulnerable)
         score += self._slam_points(declarer_tricks, vulnerable)
-        if 0:
-            print(self)
-            print('g', contract_points)
-            print('d', doubled_bonus)
-            print('c', self._game_bonus(declarer_tricks, vulnerable, contract_points))
-            print('o', self._overtrick_points(declarer_tricks, vulnerable))
-            print('s', self._slam_points(declarer_tricks, vulnerable))
         return score
 
     def _contract_points(self, declarer_tricks: int, vulnerable: bool) -> int:
@@ -327,7 +322,6 @@ class Contract(object):
 
     def _game_bonus(self, declarer_tricks: int, vulnerable: bool, contract_points: int) -> int:
         """Return the points earned for the game in a made contract."""
-        name = self.denomination.name
         if vulnerable:
             game_bonus = GAME_BONUS['vulnerable']
         else:
@@ -391,4 +385,4 @@ class Contract(object):
                 score -= points[-1]
             else:
                 score -= points[trick]
-        return score
\ No newline at end of file
+        return score
